@@ -3,6 +3,7 @@ import requests
 from bs4 import BeautifulSoup
 import json
 import openpyxl
+import sys
 
 def main():
     base_url = 'https://understat.com/match/'
@@ -157,7 +158,7 @@ def main():
             f.close()
             print("created "+ filename +".sql")
 
-            return
+            sys.exit()
 
         elif shot_style == 'point':
             filename = str(input("Please fill in the file name : "))
@@ -201,12 +202,12 @@ def main():
             f.close()
             print("created "+ filename +".sql")
 
-            return
+            sys.exit()
 
         else:
             print("The point format you entered may not be supported or may have been entered incorrectly.\nIf you made a mistake, please start over from the beginning.")
 
-            return
+            sys.exit()
     else:
         print("The file format you entered may not be supported or may have been entered incorrectly.\nIf you made a mistake, please start over from the beginning.")
 
